====================
Administration Guide
====================

Skyline is an OpenStack dashboard optimized by UI and UE. It has a modern
technology stack and ecology, is easier for developers to maintain and
operate by users, and has higher concurrency performance.

.. toctree::

   compute
   storage
   identity

For more information about dashboard, see :ref:`skyline-dashboard`.

To deploy skyline, see :ref:`skyline-installation-guide`.

To configure skyline, see
`OpenStack Skyline Settings <https://docs.openstack.org/skyline-apiserver/latest/configuration/settings.html>`__.
